@@ -36,8 +36,10 @@ function main() {
     getAccuracyDescriptionTest();
     prettyTimeTest();
     prettyDistanceTest();
+    prettyPopulationTest();
     normalizeStringTest();
     validWebsiteTest();
+    validEmailTest();
     firstToLocaleUpperCaseTest();
 }
 
@@ -97,6 +99,14 @@ function prettyDistanceTest() {
     JsUnit.assertEquals('5282 ft', Utils.prettyDistance(1610, true));
 }
 
+function prettyPopulationTest() {
+    JsUnit.assertEquals('123456', Utils.prettyPopulation(123456));
+    JsUnit.assertEquals('1234567', Utils.prettyPopulation(1234567));
+    JsUnit.assertEquals('200000', Utils.prettyPopulation(200000));
+    JsUnit.assertEquals('1M', Utils.prettyPopulation(1000000));
+    JsUnit.assertEquals('2.1M', Utils.prettyPopulation(2100000));
+}
+
 function normalizeStringTest() {
     JsUnit.assertEquals('foo', Utils.normalizeString('foo'));
     JsUnit.assertEquals('fooBar', Utils.normalizeString('fooBar'));
@@ -112,6 +122,14 @@ function validWebsiteTest() {
     JsUnit.assertEquals(false, Utils.isValidWebsite("https:gnome.org"));
 }
 
+function validEmailTest() {
+    JsUnit.assertTrue(Utils.isValidEmail('mail@example.com'));
+    JsUnit.assertTrue(Utils.isValidEmail('information.here@company.store'));
+    JsUnit.assertTrue(Utils.isValidEmail('我買@屋企.香港'));
+    JsUnit.assertFalse(Utils.isValidEmail('mailto:mail@example.com'));
+    JsUnit.assertFalse(Utils.isValidEmail('mail@no-tld'));
+}
+
 function firstToLocaleUpperCaseTest() {
     JsUnit.assertEquals('Xxx', Utils.firstToLocaleUpperCase('xxx'));
     JsUnit.assertEquals('Xxx', Utils.firstToLocaleUpperCase('Xxx'));
